@@ -5,22 +5,27 @@ from typing import Callable, List, Optional, Any, ByteString, Iterator
 
 import approvaltests.reporters.default_reporter_factory
 from approval_utilities import utils
-from approvaltests.core.format_wrapper import FormatWrapper, AlwaysMatch
+from approval_utilities.approvaltests.core.executable_command import ExecutableCommand
 from approval_utilities.approvaltests.core.verifiable import Verifiable
+from approval_utilities.list_utils import format_list
+from approval_utilities.utilities.exceptions.exception_utils import to_string
 from approval_utilities.utilities.map_reduce import first
+from approvaltests import Options
 from approvaltests.approval_exception import ApprovalException
 from approvaltests.binary_writer import BinaryWriter
 from approvaltests.core import Reporter, Writer
+from approvaltests.core.format_wrapper import FormatWrapper, AlwaysMatch
 from approvaltests.core.namer import Namer
-from approvaltests.namer.stack_frame_namer import StackFrameNamer
 from approvaltests.core.options import Options
 from approvaltests.core.scenario_namer import ScenarioNamer
 from approvaltests.existing_file_writer import ExistingFileWriter
 from approvaltests.file_approver import FileApprover
-from approval_utilities.list_utils import format_list
+from approvaltests.namer.stack_frame_namer import StackFrameNamer
 from approvaltests.reporters.diff_reporter import DiffReporter
+from approvaltests.reporters.executable_command_reporter import (
+    ExecutableCommandReporter,
+)
 from approvaltests.string_writer import StringWriter
-from approval_utilities.utilities.exceptions.exception_utils import to_string
 from approvaltests.verifiable_objects.formatter_of_argparse_namespace import (
     FormatterWrapperOfArgparseNamespace,
 )
@@ -55,7 +60,7 @@ def verify(
     errors: Optional[str] = None,
     newline: Optional[str] = None,
     *,  # enforce keyword arguments - https://www.python.org/dev/peps/pep-3102/
-    options: Optional[Options] = None
+    options: Optional[Options] = None,
 ) -> None:
     """Verify string data against a previously approved version of the string.
 
@@ -127,7 +132,7 @@ def verify_binary(
     data: ByteString,
     file_extension_with_dot: str,
     *,  # enforce keyword arguments - https://www.python.org/dev/peps/pep-3102/
-    options: Optional[Options] = None
+    options: Optional[Options] = None,
 ) -> None:
     options = initialize_options(options, None).for_file.with_extension(
         file_extension_with_dot
@@ -158,7 +163,7 @@ def verify_with_namer(
     errors: Optional[str] = None,
     newline: Optional[str] = None,
     *,  # enforce keyword arguments - https://www.python.org/dev/peps/pep-3102/
-    options: Optional[Options] = None
+    options: Optional[Options] = None,
 ) -> None:
     """Verify string data against a previously approved version of the string.
 
@@ -206,7 +211,7 @@ def verify_with_namer_and_writer(
     writer: Writer,
     reporter: Optional[Reporter] = None,
     *,  # enforce keyword arguments - https://www.python.org/dev/peps/pep-3102/
-    options: Optional[Options] = None
+    options: Optional[Options] = None,
 ) -> None:
     options = initialize_options(options, reporter)
     error = FileApprover.verify(namer, writer, options.reporter, options.comparator)
@@ -220,7 +225,7 @@ def verify_as_json(
     reporter=None,
     *,  # enforce keyword arguments - https://www.python.org/dev/peps/pep-3102/
     deserialize_json_fields=False,
-    options: Optional[Options] = None
+    options: Optional[Options] = None,
 ):
     if deserialize_json_fields:
         object_to_verify = utils.deserialize_json_fields(object_to_verify)
@@ -235,9 +240,8 @@ def verify_as_json(
 def verify_xml(
     xml_string: str,
     reporter: None = None,
-    namer: Namer = None,
     *,  # enforce keyword arguments - https://www.python.org/dev/peps/pep-3102/
-    options: Optional[Options] = None
+    options: Optional[Options] = None,
 ) -> None:
     options = initialize_options(options, reporter)
     try:
@@ -252,7 +256,7 @@ def verify_xml(
 def verify_html(
     html_string: str,
     *,  # enforce keyword arguments - https://www.python.org/dev/peps/pep-3102/
-    options: Optional[Options] = None
+    options: Optional[Options] = None,
 ) -> None:
     options = initialize_options(options)
     try:
@@ -269,7 +273,7 @@ def verify_file(
     file_name: str,
     reporter: Reporter = None,
     *,  # enforce keyword arguments - https://www.python.org/dev/peps/pep-3102/
-    options: Optional[Options] = None
+    options: Optional[Options] = None,
 ) -> None:
     """Verify the contents of a text file against previously approved contents.
 
@@ -303,7 +307,7 @@ def verify_all(
     errors: None = None,
     newline: None = None,
     *,  # enforce keyword arguments - https://www.python.org/dev/peps/pep-3102/
-    options: Optional[Options] = None
+    options: Optional[Options] = None,
 ) -> None:
     """Verify a collection of items against a previously approved collection.
 
@@ -351,7 +355,7 @@ def verify_all(
 def verify_exception(
     code_that_throws_exception: Callable,
     *,  # enforce keyword arguments - https://www.python.org/dev/peps/pep-3102/
-    options: Optional[Options] = None
+    options: Optional[Options] = None,
 ):
     result = ""
     try:
@@ -370,3 +374,17 @@ def delete_approved_file():
     filename = Path(get_default_namer().get_approved_filename())
     if filename.exists():
         filename.unlink()
+
+
+def verify_executable_command(
+    command: ExecutableCommand,
+    *,  # enforce keyword arguments - https://www.python.org/dev/peps/pep-3102/
+    options: Optional[Options] = None,
+):
+    options = initialize_options(options)
+    verify(
+        command.get_command(),
+        options=options.with_reporter(
+            ExecutableCommandReporter(command, options.reporter)
+        ),
+    )
